@@ -10,7 +10,7 @@ use Dancer::FileUtils 'path';
 use vars '$VERSION';
 use base 'Dancer::Template::Abstract';
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 my $_engine;
 
@@ -19,10 +19,12 @@ sub init {
 
     my $mt_cfg = {
         use_cache  => 0,
-        tag_start  => '<%',
-        tag_end    => '%>',
         line_start => '%',
+        tag_start  => $self->config->{start_tag} || '<%',
+        tag_end    => $self->config->{stop_tag} || '%>',
+
     };
+
     my $path = path($self->{settings}{appdir}, 'views');
     $mt_cfg->{include_path} = [$path]
       if $self->{settings} && $self->{settings}{appdir};
